/**
 * Internal dependencies
 */
import { AdminContext } from 'admin';

/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { useContext, useState } from '@wordpress/element';
import { info } from '@wordpress/icons';

import {
	PanelRow,
	ToggleControl,
	Button,
	Modal
} from '@wordpress/components';

const CursorSurroundingLinesStyle = () => {
	const { editorOptions, setEditorOptions } = useContext( AdminContext );
	const [ isModalOpen, setIsModalOpen ] = useState( false );

	const handleChange = ( value ) => {
		setEditorOptions({
			...editorOptions,
			cursorSurroundingLinesStyle: !! value ? 'all' : 'default'
		});
	};

	return (
		<PanelRow>
			<ToggleControl
				label={ __( 'Keep lines before and after the cursor even when the cursor is moved by mouse click', 'custom-html-block-extension' ) }
				checked={ 'all' === editorOptions.cursorSurroundingLinesStyle }
				onChange={ ( value ) => handleChange( value ) }
			/>
			{ isModalOpen && (
				<Modal
					title={ __( 'Keep lines before and after the cursor even when the cursor is moved by mouse click', 'custom-html-block-extension' ) }
					className="chbe-modal"
					onRequestClose={ () => setIsModalOpen( false ) }
				>
					<div className="chbe-modal__row">
						<div className="chbe-modal__col">
							<h3>{ __( 'Enable', 'custom-html-block-extension' ) }</h3>
							<Button
								isPrimary={ 'all' === editorOptions.cursorSurroundingLinesStyle }
								isTertiary={ 'all' !== editorOptions.cursorSurroundingLinesStyle }
								onClick={ () => {
									handleChange( 'all' );
									setIsModalOpen( false );
								}}
							>
								<img
									src={ chbeObj.assetPath + '/assets/images/admin/editor-config/editor-options/cursor-surrounding-lines-style_1.gif' }
									alt={ __( 'Enable', 'custom-html-block-extension' ) }
								/>
							</Button>
						</div>
						<div className="chbe-modal__col">
							<h3>{ __( 'Disable (default)', 'custom-html-block-extension' ) }</h3>
							<Button
								isPrimary={ 'default' === editorOptions.cursorSurroundingLinesStyle }
								isTertiary={ 'default' !== editorOptions.cursorSurroundingLinesStyle }
								onClick={ () => {
									handleChange( 'default' );
									setIsModalOpen( false );
								}}
							>
								<img
									src={ chbeObj.assetPath + '/assets/images/admin/editor-config/editor-options/cursor-surrounding-lines-style_2.gif' }
									alt={ __( 'Disable (default)', 'custom-html-block-extension' ) }
								/>
							</Button>
						</div>
					</div>
				</Modal>
			)}
			<Button
				className="chbe-help"
				icon={ info }
				label={ __( 'Information', 'custom-html-block-extension' ) }
				onClick={ () => setIsModalOpen( true ) }
			></Button>
		</PanelRow>
	);
};

export default CursorSurroundingLinesStyle;
